@@ -21,8 +21,8 @@ def assert_equal(x, y, message=None):
     Otherwise it does nothing.
 
     Args:
-      x (:obj:`tensorflow.Tensor`): a tensor
-      y (:obj:`tensorflow.Tensor`): a tensor of the same dtype as and broadcastable to `x`.
+      x (tf.Tensor): a tensor
+      y (tf.Tensor): a tensor of the same dtype as and broadcastable to `x`.
       message (str): A string to prefix to the default message. Defaults to None.
 
     Raises:
@@ -40,8 +40,8 @@ def assert_none_equal(x, y, message=None):
     Otherwise it does nothing.
 
     Args:
-      x (:obj:`tensorflow.Tensor`): a tensor
-      y (:obj:`tensorflow.Tensor`): a tensor of the same dtype as and broadcastable to `x`.
+      x (tf.Tensor): a tensor
+      y (tf.Tensor): a tensor of the same dtype as and broadcastable to `x`.
       message (str): A string to prefix to the default message. Defaults to None.
 
     Raises:
@@ -59,8 +59,8 @@ def assert_less(x, y, message=None):
     Otherwise it does nothing.
 
     Args:
-      x (:obj:`tensorflow.Tensor`): a tensor
-      y (:obj:`tensorflow.Tensor`): a tensor broadcastable to `x`.
+      x (tf.Tensor): a tensor
+      y (tf.Tensor): a tensor broadcastable to `x`.
       message (str): A string to prefix to the default message. Defaults to None.
 
     Raises:
@@ -78,8 +78,8 @@ def assert_less_equal(x, y, message=None):
     Otherwise it does nothing.
 
     Args:
-      x (:obj:`tensorflow.Tensor`): a tensor
-      y (:obj:`tensorflow.Tensor`): a tensor broadcastable to `x`.
+      x (tf.Tensor): a tensor
+      y (tf.Tensor): a tensor broadcastable to `x`.
       message (str): A string to prefix to the default message. Defaults to None.
 
     Raises:
@@ -97,8 +97,8 @@ def assert_rank_at_least(x, rank, message=None):
     Otherwise it does nothing.
 
     Args:
-      x (:obj:`tensorflow.Tensor`): a tensor
-      rank (:obj:`tensorflow.Tensor`): a scalar integer tensor
+      x (tf.Tensor): a tensor
+      rank (tf.Tensor): a scalar integer tensor
       message (str): A string to prefix to the default message. Defaults to None.
 
     Raises:
