@@ -85,7 +85,8 @@ class QuantizedReLU(keras.layers.Layer):
         # Express zero as a QFloat aligned with the inputs because this is what the
         # dispatched operations expect.
         # The actual hardware implementation will simply use a zero integer.
-        zero = QFloat(FixedPoint(0, inputs.fp.value_bits, inputs.fp.frac_bits), inputs.scales)
+        zero = QFloat(FixedPoint(tf.constant(0.), inputs.fp.value_bits, inputs.fp.frac_bits),
+                      inputs.scales)
 
         if self.max_value is None:
             # Just remove negative values
