@@ -51,10 +51,9 @@ class QuantizedBatchNormalization(keras.layers.Layer):
 
     .. math:: y = a \\cdot x + b
 
-    Note that this layer will hold variables with names gamma, beta,
-    moving_mean (mu), and moving_variance (sigma), so they can be converted
-    from a BatchNormalization layer. However, it's a and b that are going to
-    be quantized.
+    Note that this layer will hold variables with names gamma, beta, moving_mean (:math:`\\mu`),
+    and moving_variance (:math:`\\sigma = \\sqrt{moving\_variance + \\epsilon}`), so they can be
+    converted from a BatchNormalization layer. However, it's a and b that are going to be quantized.
 
     Args:
         quant_config (dict, optional): the serialized quantization configuration. Defaults to None.
