@@ -175,7 +175,8 @@ def tensor_inputs(supported):
                         self.buffer_bitwidth = MAX_BUFFER_BITWIDTH - 1
 
                 if (isinstance(inputs, FixedPoint) and not inputs.per_tensor
-                        and self.__class__.__name__ != 'QuantizedDepthwiseConv2D'):
+                        and self.__class__.__name__ not in
+                        ['QuantizedDepthwiseConv2D', 'QuantizedExtractToken']):
                     # Expand the inputs to a higher bitwidth to avoid saturation and align them.
                     # Depthwise layers do not require input_shift because each channel is
                     # handled by a single filter.
