@@ -151,7 +151,7 @@ class DepthwiseConv2DTranspose(DepthwiseConv2D):
 @tf.keras.utils.register_keras_serializable()
 class QuantizedDepthwiseConv2DTranspose(DepthwiseConv2DTranspose):
     """ A transposed depthwise convolutional layer that operates on quantized
-        inputs and weights.
+    inputs and weights.
 
     Args:
         quant_config (dict, optional): the serialized quantization
@@ -163,7 +163,7 @@ class QuantizedDepthwiseConv2DTranspose(DepthwiseConv2DTranspose):
         # in this very layer it will need to be set per-tensor to complete
         # the conv2d transpose operation. Weight quantizer axis is overridden,
         # and quant_config is updated accordingly.
-        self.weight_quantizer._axis = "per-tensor"
+        self.weight_quantizer.axis = "per-tensor"
         self.quant_config['weight_quantizer']['axis'] = 'per-tensor'
 
     @tensor_inputs([FixedPoint])
