@@ -30,19 +30,18 @@ from ..tensors import FixedPoint, BASE_BUFFER_BITWIDTH
 
 @tf.keras.utils.register_keras_serializable()
 class LayerMadNormalization(keras.layers.LayerNormalization):
-    r"""Approximates the :obj:`keras.layers.LayerNormalization` (LN), replacing the computation of
+    r"""Approximates the `keras.layers.LayerNormalization` (LN), replacing the computation of
     the standard deviation by the mean average deviation (mad).
 
-    Taking into account the complexity of the calculate required in the standard deviation,
-    the LayerMadNormalization (LMN) is intended to replace the :math:`std(x)` by :math:`mad(x)`
-    on a Power of Two (PoT), defined as:
+    Taking into account the complexity of computing the standard deviation, the
+    LayerMadNormalization (LMN) is intended to replace the :math:`std(x)` by :math:`mad(x)` defined
+    as:
 
-    .. math:: mad(x) = |x - mean(x)| * 2^\text{-nb_channels}
+    .. math:: mad(x) = \frac{sum(|x - mean(x)|)}{nb\_channels}
 
-    To simplify it even more and make it more hardware-friendly, :math:`mean(x)` is considered
-    as 0, so. These are the resulting calculations:
+    To simplify it even more and make it more hardware-friendly, :math:`mean(x)` is zeroed:
 
-    .. math:: mad(x) = sum(|x|) * 2^\text{-nb_channels}
+    .. math:: mad(x) = \frac{sum(|x|)}{nb\_channels}
 
     Then, the equation of the layer is defined as:
 
@@ -63,14 +62,14 @@ class LayerMadNormalization(keras.layers.LayerNormalization):
         """Compute the mean absolute deviation (mad).
 
         Args:
-            inputs (:obj:`tensorflow.Tensor`): input tensor.
+            inputs (tf.Tensor): input tensor.
             axis (array of ints): axis along which to compute mad.
             name (str, optional): name used to scope the operations that compute the mad.
                 Defaults to None.
             *args, **kwargs (dict, optional): additional arguments of :func:`tf.math.reduce_sum`.
 
         Returns:
-            :obj:`tensorflow.Tensor`: mean absolute deviation (mad).
+            tf.Tensor: mean absolute deviation (mad).
         """
         # Compute the mad
         with ops.name_scope(name, "_mad", [inputs, axis]):
