@@ -25,7 +25,7 @@ from keras.utils import conv_utils
 from .decorators import (register_quantize_target, register_no_output_quantizer, rescale_outputs,
                          tensor_inputs)
 from .quantizers import OutputQuantizer
-from ..tensors import FixedPoint, QTensor, MAX_BUFFER_BITWIDTH
+from ..tensors import FixedPoint, QTensor, QFloat, MAX_BUFFER_BITWIDTH
 
 
 @register_quantize_target(MaxPool2D)
@@ -74,8 +74,9 @@ class QuantizedGlobalAveragePooling2D(GlobalAveragePooling2D):
 
     def build(self, input_shape):
         super().build(input_shape)
-        # Build the spatial size
+        # Build the spatial size and its reciprocal
         self.spatial_size = (input_shape[1] * input_shape[2])
+        self.spatial_size_rec = 1. / self.spatial_size
 
     @tensor_inputs([QTensor])
     @rescale_outputs
@@ -85,6 +86,8 @@ class QuantizedGlobalAveragePooling2D(GlobalAveragePooling2D):
         if isinstance(inputs, FixedPoint):
             inputs.assert_per_tensor()
         inputs_sum = tf.reduce_sum(inputs, axis=[1, 2], keepdims=self.keepdims)
+        if isinstance(inputs, FixedPoint):
+            return QFloat(inputs_sum, self.spatial_size_rec)
         return inputs_sum / self.spatial_size
 
     def get_config(self):
