@@ -30,11 +30,11 @@ class Quantizer(Layer):
     The bitwidth defines the number of quantization levels on which the
     values will be quantized.
     For a quantizer that accepts unsigned values, the maximum quantization
-    level is 2 ^ bitwidth - 1.
+    level is :math:`2 ^ {bitwidth} - 1`.
     For a quantizer that accepts signed values, we lose one bit of precision to
     store the sign.
     When the quantizer is signed, the quantization interval is asymmetric around
-    zero (i.e range: [- 2 ^ (bitwidth - 1), 2 ^ (bitwidth - 1) - 1]).
+    zero (i.e range: :math:`[- 2 ^ {bitwidth - 1}, 2 ^ {bitwidth - 1} - 1]`).
 
     Args:
         bitwidth (int): the quantization bitwidth.
@@ -103,10 +103,10 @@ class Dequantizer(Layer):
         """Convert QTensor inputs to float.
 
         Args:
-            inputs (:obj:`tensorflow.Tensor` or :obj:`QTensor`): the inputs tensor(s).
+            inputs (tf.Tensor or :obj:`QTensor`): the inputs tensor(s).
 
         Returns:
-            :obj:`tensorflow.Tensor`: the dequantized tensor(s).
+            tf.Tensor: the dequantized tensor(s).
         """
 
         def dequantize(x, frac_bits_recorder=None, scales_recorder=None):
