@@ -30,8 +30,9 @@ class WeightQuantizer(Quantizer):
 
     In order, the WeightQuantizer:
 
-        - evaluates the scales required to align the quantization ranges on powers of two,
-        - quantizes the rescaled Tensor and returns a QFloat.
+        - evaluates the scales required to align the values on optimal ranges for FixedPoint
+          quantization,
+        - quantizes the rescaled Tensor as a FixedPoint and returns a QFloat.
 
     Args:
         bitwidth (int, optional): the quantization bitwidth, defaults to 4.
@@ -43,7 +44,7 @@ class WeightQuantizer(Quantizer):
 
     def __init__(self, bitwidth=4, signed=True, axis="per-axis", **kwargs):
         super().__init__(bitwidth, signed, **kwargs)
-        self._axis = axis
+        self.axis = axis
         if not (isinstance(axis, str) and axis in ["per-tensor", "per-axis"]):
             raise ValueError(f"Only support reduction 'per-tensor' or 'per-axis'. Given {axis}.")
         self.qweights = QFloatRecorder()
@@ -55,16 +56,16 @@ class WeightQuantizer(Quantizer):
             input_shape (list): the shape of input tensor.
         """
         # Convert axis to a list of int
-        if self._axis == "per-axis" and len(input_shape) > 1:
+        if self.axis == "per-axis" and len(input_shape) > 1:
             axis_list = list(range(len(input_shape) - 1))
             # When input_shape last dimension is 1, move operation from axis -1 to axis -2 by
             # adding 1 to the last element in the list. Practical use case is for Depthwise kernels
             # that will be quantized per-channel.
             if input_shape[-1] == 1 and len(input_shape) > 2:
                 axis_list[-1] = axis_list[-1] + 1
-            self.axis = axis_list
+            self._axis = axis_list
         else:
-            self.axis = None
+            self._axis = None
 
     def call(self, inputs):
         """Quantize the float inputs
@@ -75,7 +76,7 @@ class WeightQuantizer(Quantizer):
             2. Quantize the inputs.
 
         Args:
-            inputs (:obj:`tensorflow.Tensor`): the inputs tensor.
+            inputs (tf.Tensor): the inputs tensor.
 
         Returns:
             :obj:`QFloat`: the quantized tensor.
@@ -86,15 +87,15 @@ class WeightQuantizer(Quantizer):
                 " inputs.")
 
         # Compute the quantization ranges from the inputs
-        ranges = tf.math.reduce_max(tf.math.abs(inputs), self.axis)
-        if self.axis is not None and inputs.shape[-1] == 1 and len(inputs.shape) > 2:
+        ranges = tf.math.reduce_max(tf.math.abs(inputs), self._axis)
+        if self._axis is not None and inputs.shape[-1] == 1 and len(inputs.shape) > 2:
             # Expand the shape of the ranges so that it is broacastable on the inputs
             ranges = tf.expand_dims(ranges, -1)
         # Evaluate the scales to align on the optimal quantization ranges
         scales = QFloat.optimal_scales(ranges, self.value_bits)
         # Clip scales lower bound to avoid quantizing very tiny values. Minimum is defined
         # as 1e-6, enough value to be considered as zero.
-        scales = tf.clip_by_value(scales, 1e-6, tf.reduce_max(scales))
+        scales = tf.maximum(scales, 1e-6)
         # Since we use the optimal quantization ranges [-int_max -1, int_max], the inner
         # FixedPoint can be quantized with exactly zero fractional bits
         qweights = QFloat.quantize(inputs, self.value_bits, scales, 0.)
@@ -109,5 +110,5 @@ class WeightQuantizer(Quantizer):
             dict: the config of the layer.
         """
         config = super().get_config()
-        config.update({"axis": self._axis})
+        config.update({"axis": self.axis})
         return config
