@@ -81,7 +81,7 @@ class TensorRecorder(Recorder, keras.layers.Layer):
         """Get the recorded value.
 
         Returns:
-            :obj:`tf.Tensor`: value of the stored record or None.
+            tf.Tensor: value of the stored record or None.
         """
         return None if self._var is None else self._var.value()
 
@@ -89,10 +89,10 @@ class TensorRecorder(Recorder, keras.layers.Layer):
         """Record the values of the inputs if recording is True.
 
         Args:
-            inputs (:obj:`tf.Tensor`): new values.
+            inputs (tf.Tensor): new values.
 
         Returns:
-            :obj:`tf.Tensor`: the inputs.
+            tf.Tensor: the inputs.
         """
         if self.recording:
             if self._var is None:
