@@ -14,28 +14,40 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ******************************************************************************
-import tensorflow as tf
-import keras
-
-from ...tensors import FixedPoint
-
 
 __all__ = ["QuantizedFlatten"]
 
+import tensorflow as tf
+import keras
+import functools
+import operator
 
+from ..decorators import (register_quantize_target, tensor_inputs, register_no_output_quantizer,
+                          register_aligned_inputs)
+from ..recorders import TensorRecorder
+from ...tensors import FixedPoint
+
+
+@register_quantize_target(keras.layers.Flatten)
+@register_no_output_quantizer
+@register_aligned_inputs
 @tf.keras.utils.register_keras_serializable()
 class QuantizedFlatten(keras.layers.Flatten):
     """A Flatten layer that operates on quantized inputs
     """
 
+    @tensor_inputs([FixedPoint])
     def call(self, inputs):
-        # raise an error if the inputs are not FixedPoint
-        if not isinstance(inputs, FixedPoint):
-            raise TypeError("QuantizedFlatten only accepts FixedPoint inputs. "
-                            f"Receives {type(inputs)} inputs.")
-        if inputs.frac_bits.shape.ndims:
-            raise ValueError("QuantizedFlatten only supports inputs quantized per-tensor.")
-        # Flatten the values
-        flattened_values = super().call(inputs.values)
-        # Return a new reshaped FixedPoint
-        return FixedPoint(flattened_values, inputs.value_bits, inputs.frac_bits)
+        if not inputs.per_tensor:
+            inputs, shift = inputs.expand(inputs.value_bits)
+            if getattr(self, 'input_shift', None) is None:
+                with tf.init_scope():
+                    self.input_shift = TensorRecorder(name="input_shift")
+            self.input_shift(shift)
+        if tf.executing_eagerly():
+            flattened_shape = tf.constant([inputs.shape[0], -1])
+        else:
+            non_batch_dims = inputs.shape[1:]
+            last_dim = int(functools.reduce(operator.mul, non_batch_dims))
+            flattened_shape = tf.constant([-1, last_dim])
+        return tf.reshape(inputs, flattened_shape)
