@@ -57,7 +57,7 @@ def shiftmax(logits, axis=-1):
     We take :math:`x0 = max(logits)`.
 
     Args:
-        logits (:obj:`tf.Tensor`): a non-empty `Tensor`.
+        logits (tf.Tensor): a non-empty `Tensor`.
         axis (int, list, optional): the dimension shiftmax would be performed
             on. The default is -1 which indicates the last dimension.
 
