@@ -20,9 +20,10 @@ import tensorflow as tf
 
 from keras import Model, layers
 
-from .utils import deep_clone_model, find_layer_config
+from .utils import deep_clone_model
 from .transforms import (insert_layer, align_rescaling, invert_batchnorm_pooling, fold_batchnorms,
-                         align_relu_max_value, remove_zeropadding2d, invert_relu_maxpool)
+                         align_relu_max_value, remove_zeropadding2d, invert_relu_maxpool,
+                         replace_lambda)
 from ..layers import (OutputQuantizer, WeightQuantizer, QuantizedReLU, Dequantizer, quantization,
                       QuantizationParams, get_quantization_params, UnfoldPatches, FoldPatches,
                       Attention, QuantizedConv2D, QuantizedDepthwiseConv2D,
@@ -39,7 +40,7 @@ def get_quantized_layer(layer):
     """ Returns the quantized version of the layer.
 
     Args:
-        layer (keras.Layer): layer of interest
+        layer (keras.layers.Layer): layer of interest
 
     Returns:
         keras.layer: quantized version of the layer if it exists, None otherwise.
@@ -51,7 +52,7 @@ def is_quantized_layer(layer):
     """ Returns True when the layer is a quantized layer.
 
     Args:
-        layer (keras.Layer): layer of interest
+        layer (keras.layers.Layer): layer of interest
 
     Returns:
         bool: True when the layer is a quantized layer, False otherwise.
@@ -218,28 +219,27 @@ def quantize(model, q_config=None, qparams=QuantizationParams()):
 
     - `q_config` has priority over `qparams`, meaning that when a match is found in `q_config` the
       given configuration will be used instead of `qparams`. This is useful to handle specific cases
-     (e.g per-tensor output quantizer).
+      (e.g per-tensor output quantizer).
     - when no configuration is given, quantization parameters are deduced from `qparams` and
       OutputQuantizers are automatically set on appropriate layers.
     - `qparams` are only applied to 'float' Keras layers when they are first quantized. As a result,
       when re-quantizing a model, one must provide a complete `q_config`. This is made easy with the
       `dump_config` helper.
 
-    About `q_config`: it is a dictionary mapping layer names to their quantization configuration.
-    While the name matching will first look for exact name matches, layer names keys can also be
-    expressed as regular expressions to match with several layers.
-
     If not already present, a final Dequantizer will be added at the end of the Model.
 
     Args:
         model (keras.Model): the model to quantize
-        q_config (dict, optional): quantization configuration. Defaults to None.
+        q_config (dict, optional): quantization configuration as a dictionary mapping layer names to
+            their quantization configuration. Defaults to None.
         qparams (QuantizationParams, optional): global quantization parameters. Defaults to
             QuantizationParams().
 
     Returns:
         keras.Model: the quantized model
     """
+    q_config = q_config or dict()
+
     # Layers will no longer be quantized as soon as a Dequantizer is found
     quantization_stopped = False
 
@@ -248,7 +248,8 @@ def quantize(model, q_config=None, qparams=QuantizationParams()):
     # quantized.
     input_qparams = QuantizationParams(activation_bits=qparams.activation_bits,
                                        per_tensor_activations=qparams.per_tensor_activations,
-                                       weight_bits=qparams.input_weight_bits)
+                                       weight_bits=qparams.input_weight_bits,
+                                       output_bits=qparams.output_bits)
 
     def _replace_layer(layer):
         nonlocal quantization_stopped, out_quantizer_configs, input_qparams
@@ -307,7 +308,7 @@ def quantize(model, q_config=None, qparams=QuantizationParams()):
         if quantization_stopped:
             return layer.from_config(config)
 
-        match_conf = find_layer_config(layer.name, q_config)
+        match_conf = q_config.get(layer.name, None)
         try:
             # Overwrite quantization context with input_qparams
             if input_qparams:
@@ -324,6 +325,9 @@ def quantize(model, q_config=None, qparams=QuantizationParams()):
             input_qparams = False
         return qlayer
 
+    # Replace lambda layers
+    model = replace_lambda(model)
+
     # Align Rescaling (if needed)
     model = align_rescaling(model)
 
