@@ -32,7 +32,7 @@ def record_quantization_variables(model):
     recording of all dynamic quantization objects.
 
     Args:
-        model (:class:`keras.models.Model`): model for which objects need to be recorded.
+        model (keras.Model): model for which objects need to be recorded.
     """
     def _gen_dummy_sample(shape):
         sample = np.random.randint(0, 255, size=(1, *shape))
