@@ -18,24 +18,23 @@
 Common utility methods used in quantization models.
 """
 
-__all__ = ['load_model', 'deep_clone_model', 'find_layer_config']
+__all__ = ['load_model', 'deep_clone_model', 'apply_weights_to_model']
 
-import re
 import warnings
 
 from keras.models import clone_model, load_model as kload_model
 
 
 def load_model(model_path, custom_layers=None, compile_model=True):
-    """Loads a model with Vision Transformer custom layers.
+    """Loads a model with quantizeml custom layers.
 
     Args:
         model_path (str): path of the model to load
-        custom_layers (dict, optional): custom layers to add to the model. Defaults to {}.
+        custom_layers (dict, optional): custom layers to add to the model. Defaults to None.
         compile_model (bool, optional): whether to compile the model. Defaults to True.
 
     Returns:
-        :class:`keras.models.Model`: the loaded model
+        keras.Model: the loaded model
     """
     return kload_model(model_path, custom_objects=custom_layers, compile=compile_model)
 
@@ -45,11 +44,11 @@ def deep_clone_model(model, *args, **kwargs):
     and new layers have not the same number of parameters as the original layer.
 
     Args:
-        model (:class:`keras.models.Model`): model to be cloned
+        model (keras.Model): model to be cloned
         args, kwargs (optional): arguments pass to :func:`keras.models.clone_model` function
 
     Returns:
-        :class:`keras.models.Model`: the cloned model
+        keras.Model: the cloned model
     """
     new_model = clone_model(model, *args, **kwargs)
     variables_dict = {var.name: var for var in model.variables}
@@ -84,30 +83,3 @@ def apply_weights_to_model(model, weights, verbose=True):
                 break
         if not value_applied and verbose:
             warnings.warn(f"Variable '{key}' not found in the model.")
-
-
-def find_layer_config(layer_name, qconfig=None):
-    """ Extract the layer quantization parameters from the overall quantization config file.
-
-    Args:
-        layer_name (str): the target layer name
-        qconfig (dict, optional): quantization configuration. Defaults to None.
-
-    Returns:
-        dict: layer quantization configuration
-    """
-    qconfig = qconfig or dict()
-    # Extract configuration matching patterns
-    patterns = list(qconfig.keys())
-
-    # First check if we have an exact match
-    if layer_name in patterns:
-        return qconfig[layer_name]
-
-    # Sort patterns by decreasing length and look for a match
-    patterns = sorted(patterns, key=len, reverse=True)
-    for pattern in patterns:
-        if re.search(pattern, layer_name):
-            return qconfig[pattern]
-
-    return None
