@@ -16,7 +16,7 @@
 # ******************************************************************************
 import tensorflow as tf
 
-from .qtensor import QTensor, round_through, floor_through, pow2, ceil_log2
+from .qtensor import QTensor, saturate, round_through, floor_through, pow2, ceil_log2
 from ..debugging import assert_equal, assert_none_equal, assert_less, assert_less_equal
 
 
@@ -25,14 +25,14 @@ class FixedPoint(QTensor):
 
     The value_bits parameter sets the maximum integer values that can be stored:
 
-        int_max = 2^bits - 1.
+    .. math:: int\_max = 2^{bits} - 1.
 
-    When a QTensor is created, its values are clipped to [-int_max-1, int_max].
+    When a FixedPoint is created, its values are clipped to [-int_max-1, int_max].
 
     Args:
-        values (:obj:`tensorflow.Tensor`): a tensor of integer values
+        values (tf.Tensor): a tensor of integer values
         value_bits (int): the number of value bits.
-        frac_bits (:obj:`tensorflow.Tensor`): an integer tensor of fractional bits.
+        frac_bits (tf.Tensor): an integer tensor of fractional bits.
     """
     values: tf.Tensor = 1.0
     value_bits: int = 7
@@ -51,7 +51,7 @@ class FixedPoint(QTensor):
         else:
             values = tf.convert_to_tensor(values, dtype=tf.float32)
         # Clamp to fixed-point boundaries
-        self.values = QTensor.clamp(values, value_bits)
+        self.values = saturate(values, tf.cast(value_bits, tf.float32))
         self.shape = self.values.shape
 
     @property
@@ -66,21 +66,24 @@ class FixedPoint(QTensor):
     def max_frac_bits(value_bits, ranges, clamp=True):
         """Evaluate the maximum fractional bit index for the quantization ranges.
 
-        This method evaluates the minimum number of integer bits required to cover
-        the specified quantization ranges (this can be a negative number if the
-        ranges are strictly lower than 0.5).
-        From that it deduces the rightmost fractional bit indices. This can also be a negative
-        number if the ranges are higher than the biggest integer than can be represented with the
-        specified value bits)
-        If specified, it clamps the results to the available value_bits.
+        This method evaluates the minimum number of integer bits required to cover the specified
+        quantization ranges (this can be a negative number if the ranges are strictly lower than
+        0.5).
+
+        From that it deduces the rightmost fractional bit indices.
+
+        The resulting frac_bits can be a negative number if the ranges are higher than the biggest
+        integer than can be represented with the specified value bits).
+
+        If specified, the maximum fractional bits are clamped to the available value_bits.
 
         Args:
             value_bits (int): the number of value bits.
-            ranges (:obj:`tensorflow:Tensor`): a tensor of float quantization ranges.
+            ranges (tf:Tensor): a tensor of float quantization ranges.
             clamp (bool, optional): clamp the results to self.value_bits. Defaults to True.
 
         Returns:
-            :obj:`tensorflow:Tensor`: a tensor of fractional bits.
+            tf:Tensor: a tensor of fractional bits.
         """
         # Get the powers of two containing the quantization ranges
         int_bits = ceil_log2(ranges)
@@ -99,34 +102,34 @@ class FixedPoint(QTensor):
 
         .. math:: {x_{int}} = round(x * 2^{frac\_bits})
 
-        Note: 2^-frac_bits represents the FixedPoint precision.
+        Note: :math:`2^{-frac\_bits}` represents the FixedPoint precision.
 
         Before returning, the resulting integer values are clipped to the
         maximum integer values that can be stored for the specified value bits:
 
-            [-2^value_bits, 2^value_bits - 1]
+        .. math:: [-2^{value\_bits}, 2^{value\_bits} - 1]
 
         If frac_bits is not specified, the method starts by evaluating the number
         of bits to dedicate to represent the integer part of the float tensor,
         clipped to value_bits:
 
-        .. math:: int_bits = ceil(log2(x))
+        .. math:: int\_bits = ceil(log2(x))
 
-        Note: this number can be negative when x < 1.
+        Note: this number can be negative when x < 0.5.
 
         It then evaluates the offset of the least significant bit of the fractional
         part of the float starting from zero. This represents the fractional bits:
 
-        .. math:: frac_bits = value_bits - int_bits
+        .. math:: frac\_bits = value\_bits - int\_bits
 
         Args:
-            x (:obj:`tensorflow.Tensor`): a tensor of float values.
+            x (tf.Tensor): a tensor of float values.
             value_bits (int): the number of value bits
-            frac_bits (:obj:`tensorflow.Tensor`, optional): an integer tensor of fractional bits.
+            frac_bits (tf.Tensor, optional): an integer tensor of fractional bits.
                 Defaults to None.
 
         Returns:
-            a :obj:`FixedPoint`
+            :obj:`FixedPoint`: the FixedPoint tensor
         """
         if frac_bits is None:
             if isinstance(x, int) or tf.reduce_all(x == tf.math.round(x)):
@@ -135,7 +138,7 @@ class FixedPoint(QTensor):
             else:
                 frac_bits = FixedPoint.max_frac_bits(value_bits, tf.abs(x))
         # Project float into fixed-point representation space
-        x_scaled = x * pow2(frac_bits)
+        x_scaled = tf.math.multiply(x, pow2(frac_bits), name="quantize")
         # Round or ceil to obtain integer values
         values = round_through(x_scaled)
         return FixedPoint(values, value_bits, frac_bits)
@@ -186,8 +189,8 @@ class FixedPoint(QTensor):
             value_bits (int, optional): the target value bits. Defaults to None.
 
         Returns:
-            tuple(:obj:`FixedPoint`, :obj:`tf.Tensor`): a new FixedPoint with aligned
-                fractional bits and the shift that was applied.
+            tuple(:obj:`FixedPoint`, tf.Tensor): a new FixedPoint with aligned
+            fractional bits and the shift that was applied.
         """
         if not isinstance(other, FixedPoint):
             raise ValueError("Other must be a FixedPoint.")
@@ -198,7 +201,7 @@ class FixedPoint(QTensor):
         """Reduce the precision of a FixedPoint
 
         Args:
-            frac_bits (:obj:`tensorflow.Tensor`): the target fractional bits
+            frac_bits (tf.Tensor): the target fractional bits
 
         Returns:
             :obj:`FixedPoint`: the downscaled FixedPoint
@@ -228,7 +231,7 @@ class FixedPoint(QTensor):
         - expand a FixedPoint to a larger bitwidth after having increased its precision.
 
         Args:
-            frac_bits (:obj:`tensorflow.Tensor`): the target fractional bits
+            frac_bits (tf.Tensor): the target fractional bits
             value_bits (int, optional): the target value bits
 
         Returns:
@@ -249,7 +252,8 @@ class FixedPoint(QTensor):
         # - the rounding by adding 0.5 and flooring (to workaround banker's rounding).
         # For positive shift, the results being integer, the rounding has no effect.
         # We therefore apply the same operations for both shifts.
-        values = floor_through(self.values * pow2(shift) + 0.5)
+        values = tf.math.multiply(self.values, pow2(shift), name="rescale")
+        values = floor_through(values + 0.5)
         # return a new FixedPoint with the target precision and bitwidth
         return FixedPoint(values, value_bits, frac_bits), shift
 
@@ -259,7 +263,7 @@ class FixedPoint(QTensor):
         The target precision must be higher than the current one.
 
         Args:
-            frac_bits (:obj:`tensorflow.Tensor`): the target fractional bits
+            frac_bits (tf.Tensor): the target fractional bits
             value_bits (int, optional): the target value bits
 
         Returns:
@@ -277,7 +281,7 @@ class FixedPoint(QTensor):
                     f"Cannot upscale {self.name} to {frac_bits} fractional bits as it saturates its"
                     f" {value_bits}-bit buffer.")
         # Apply shift
-        values = self.values * pow2(shift)
+        values = tf.math.multiply(self.values, pow2(shift), name="upscale")
         # return a new FixedPoint with the target precision and bitwidth
         return FixedPoint(values, value_bits, frac_bits), shift
 
@@ -295,8 +299,8 @@ class FixedPoint(QTensor):
             value_bits (int): the target value_bits
 
         Returns:
-            tuple(:obj:`FixedPoint`, :obj:`tf.Tensor`): a new FixedPoint with expanded
-                fractional bits and the shift that was applied.
+            tuple(:obj:`FixedPoint`, tf.Tensor): a new FixedPoint with expanded
+            fractional bits and the shift that was applied.
         """
         if value_bits < self.value_bits:
             raise ValueError(
@@ -311,7 +315,7 @@ class FixedPoint(QTensor):
 
     @staticmethod
     def _lshift(values, shift):
-        return values * pow2(shift)
+        return tf.math.multiply(values, pow2(shift), name="lshift")
 
     def shift(self, s):
         """Apply a tensor-wide left or right shift.
@@ -329,12 +333,13 @@ class FixedPoint(QTensor):
         left-shift and flooring is applied on right-shift.
 
         Args:
-            s (:obj:`tensorflow.Tensor`): the shift values for each pixel.
+            s (tf.Tensor): the shift values for each pixel.
 
         Returns:
             :obj:`FixedPoint`: the result as a FixedPoint
         """
-        values = floor_through(self.values * pow2(s))
+        values = tf.math.multiply(self.values, pow2(s), name="shift")
+        values = floor_through(values)
         return FixedPoint(values, self.value_bits, self.frac_bits)
 
     def __rshift__(self, shift):
@@ -344,7 +349,7 @@ class FixedPoint(QTensor):
         of the corresponding float by a power-of-two, then a flooring to the quantization interval.
 
         Args:
-            shift (:obj:`tensorflow.Tensor`): the power of 2 to divide by
+            shift (tf.Tensor): the power of 2 to divide by
 
         Returns:
             :obj:`FixedPoint`: the result as a FixedPoint
@@ -373,7 +378,7 @@ class FixedPoint(QTensor):
         quantization interval.
 
         Args:
-            shift (:obj:`tensorflow.Tensor`): the power of 2 to multiply by
+            shift (tf.Tensor): the power of 2 to multiply by
 
         Returns:
             :obj:`FixedPoint`: the result as a FixedPoint
@@ -421,17 +426,6 @@ class FixedPoint(QTensor):
         raise TypeError(
             f"Unsupported operand type(s) for -: 'FixedPoint' and '{type(other)}'")
 
-    def __mul__(self, other):
-        if isinstance(other, int):
-            return self * FixedPoint(other)
-        elif isinstance(other, FixedPoint):
-            # The product between fixed-point is straight-forward
-            p_values = self.values * other.values
-            # Return a new FixedPoint whose frac bits is the sum of both terms
-            return FixedPoint(p_values, self.value_bits, self.frac_bits + other.frac_bits)
-        raise TypeError(
-            f"Unsupported operand type(s) for *: 'FixedPoint' and '{type(other)}'")
-
     def __truediv__(self, other):
         @tf.function
         @tf.custom_gradient
@@ -523,8 +517,8 @@ class FixedPoint(QTensor):
         """Floors the FixedPoint
 
         Returns:
-            tuple(:obj:`FixedPoint`, :obj:`tf.Tensor`): a new FixedPoint without
-                fractional bits and the shift that was applied.
+            tuple(:obj:`FixedPoint`, tf.Tensor): a new FixedPoint without
+            fractional bits and the shift that was applied.
         """
         # Divide values to remove fractional bits
         values = FixedPoint._rshift(self.values, self.frac_bits)
