@@ -37,7 +37,7 @@ class QFloat(QTensor):
 
     Args:
         fp (:obj:`FixedPoint`): a FixedPoint of values
-        scales (:obj:`tensorflow.Tensor`): a Tensor of scales
+        scales (tf.Tensor): a Tensor of scales
     """
     fp: FixedPoint = FixedPoint(1.0, 32, 0)
     scales: tf.Tensor = 1.0
@@ -79,12 +79,12 @@ class QFloat(QTensor):
 
         Args:
             value_bits (int): the number of value bits.
-            ranges (:obj:`tensorflow:Tensor`): a tensor of float quantization ranges.
-            scales (:obj:`tensorflow:Tensor`): the scales to apply to the quantization ranges.
+            ranges (tf.Tensor): a tensor of float quantization ranges.
+            scales (tf.Tensor): the scales to apply to the quantization ranges.
             clamp (bool, optional): clamp the results to self.value_bits. Defaults to True.
 
         Returns:
-            :obj:`tensorflow:Tensor`: a tensor of fractional bits.
+            tf.Tensor: a tensor of fractional bits.
         """
         return FixedPoint.max_frac_bits(value_bits, ranges / scales, clamp)
 
@@ -93,17 +93,18 @@ class QFloat(QTensor):
         """Evaluates the optimal QFloat scales for quantization ranges.
 
         We choose the optimal quantization range for a given bitwidth as:
-            [-int_max, int_max], with int_max = 2^bits - 1.
+
+            [-int_max, int_max], with :math:`int\_max = 2^{bits} - 1`.
 
         This methods evaluates the scales as the ratio to align the specified ranges
         to the optimal ranges.
 
         Args:
-            ranges (:obj:`tensorflow.Tensor`): a tensor of quantization ranges.
+            ranges (tf.Tensor): a tensor of quantization ranges.
             value_bits (int): the number of value bits.
 
         Returns:
-            :obj:`tensorflow.Tensor`: the optimal scales.
+            tf.Tensor: the optimal scales.
         """
         # Evaluate the scales as the ratio to align the ranges on the optimal quantization range
         optimal_ranges = QTensor.int_max(value_bits)
@@ -115,7 +116,7 @@ class QFloat(QTensor):
         """Quantizes the QFloat scales with the specified bitwidth.
 
         Args:
-            scales (:obj:`tensorflow.Tensor`): a tensor of float scales.
+            scales (tf.Tensor): a tensor of float scales.
             scale_bits (int): the number of scales bits.
 
         Returns:
@@ -137,9 +138,9 @@ class QFloat(QTensor):
         The resulting integer values are clipped to [-int_max-1, int_max].
 
         Args:
-            x (:obj:`tensorflow.Tensor`): a tensor of float values.
+            x (tf.Tensor): a tensor of float values.
             value_bits (int): the number of value bits.
-            scales (:obj:`tensorflow.Tensor`): a tensor of alignment scales.
+            scales (tf.Tensor): a tensor of alignment scales.
             frac_bits (int): the inner FixedPoint fractional bits (defaults to 0).
 
         Returns:
@@ -155,7 +156,7 @@ class QFloat(QTensor):
         """Returns a float representation of the QFloat
 
         Returns:
-            :obj:`tensorflow.Tensor`: the float representation.
+            tf.Tensor: the float representation.
         """
         return self.fp.to_float() * self.scales
 
@@ -171,7 +172,7 @@ class QFloat(QTensor):
         # Quantize the scales
         scales = QFloat.quantize_scales(self.scales, scale_bits)
         # Return the FixedPoint product of scales and values
-        return self.fp * scales, scales
+        return tf.math.multiply(self.fp, scales, name="apply_scales"), scales
 
     def upscale(self, frac_bits, value_bits=None):
         """Align a QFloat to a specified precision
@@ -179,7 +180,7 @@ class QFloat(QTensor):
         The target precision must be higher than the current one.
 
         Args:
-            frac_bits (:obj:`tensorflow.Tensor`): the target fractional bits
+            frac_bits (tf.Tensor): the target fractional bits
             value_bits (int, optional): the target value bits (defaults to current value bits)
 
         Returns:
