@@ -381,7 +381,7 @@ def fp_fp_conv2d_transpose(
             NHWC data format or [batch, in_channels, height, width] for NCHW data format.
         filters (:obj:`FixedPoint`): A FixedPoint with a [height, width, out_channels, in_channels]
             shape. Filter's in_channels dimension must match that of input.
-        output_shape (:obj:`tensorflow.Tensor`): A 1-D Tensor representing the output shape of the
+        output_shape (tf.Tensor): A 1-D Tensor representing the output shape of the
             deconvolution op.
         strides (list, optional): Sequence of N ints >= 1. Specifies the output stride.
             Defaults to None.
@@ -430,7 +430,7 @@ def fp_qf_conv2d_transpose(
             NHWC data format or [batch, in_channels, height, width] for NCHW data format.
         filters (:obj:`QFloat`): A QFloat of shape [height, width, out_channels, in_channels]
             shape. Filter's in_channels dimension must match that of input.
-        output_shape (:obj:`tensorflow.Tensor`): A 1-D Tensor representing the output shape of the
+        output_shape (tf.Tensor): A 1-D Tensor representing the output shape of the
             deconvolution op.
         strides (list, optional): Sequence of N ints >= 1. Specifies the output stride.
             Defaults to None.
