@@ -72,7 +72,7 @@ def fp_brodcast_to(input: FixedPoint, shape, name=None):
 
     Args:
         input (:obj:`FixedPoint`): a FixedPoint to broadcast.
-        shape (:obj:`tf.Tensor`): an 1-D `int` Tensor representing
+        shape (tf.Tensor): an 1-D `int` Tensor representing
             the shape of the desired output. Must be one of the
             following types: `int32`, `int64`.
         name (str, optional): a name for the operation. Defaults to None.
@@ -94,7 +94,7 @@ def qf_brodcast_to(input: QFloat, shape, name=None):
 
     Args:
         input (:obj:`QFloat`): a QFloat to broadcast.
-        shape (:obj:`tf.Tensor`): an 1-D `int` Tensor representing
+        shape (tf.Tensor): an 1-D `int` Tensor representing
             the shape of the desired output. Must be one of the
             following types: `int32`, `int64`.
         name (str, optional): a name for the operation. Defaults to None.
@@ -311,7 +311,7 @@ def fp_pad(tensor: FixedPoint,
 
     Args:
         tensor (:obj:`FixedPoint`): the input FixedPoint.
-        paddings (:obj:`tensorflow.Tensor`): A `Tensor` of type `int32`.
+        paddings (tf.Tensor): A `Tensor` of type `int32`.
         mode (str): must be "CONSTANT".
         constant_values (:obj:`FixedPoint`): the scalar pad value to use.
         name (str): A name for the operation (optional).
@@ -340,7 +340,7 @@ def qf_pad(tensor: QFloat,
 
     Args:
         tensor (:obj:`QFloat`): the input QFloat.
-        paddings (:obj:`tensorflow.Tensor`): A `Tensor` of type `int32`.
+        paddings (tf.Tensor): A `Tensor` of type `int32`.
         mode (str): must be "CONSTANT".
         constant_values (:obj:`QFloat`): the scalar pad value to use.
         name (str): A name for the operation (optional).
